jQuery File Upload Demo - Basic Plus version
Description: File Upload widget with multiple file selection, drag&drop support, progress bar, validation and preview images, audio and video for jQuery. Supports cross-domain, chunked and resumable file uploads. Works with any server-side platform (Google App Engine, PHP, Python, Ruby on Rails, Java, etc.) that supports standard HTML form file uploads.

# jQuery File Upload Demo

## Basic Plus version

> File Upload widget with multiple file selection, drag&drop support, progress bar, validation and preview images, audio and video for jQuery.
> Supports cross-domain, chunked and resumable file uploads and client-side image resizing.
> Works with any server-side platform (PHP, Python, Ruby on Rails, Java, Node.js, Go etc.) that supports standard HTML form file uploads.

Add files...

### Demo Notes

- The maximum file size for uploads in this demo is 5 MB (default file size is unlimited).
- Only image files (JPG, GIF, PNG) are allowed in this demo (by default there is no file type restriction).
- Uploaded files will be deleted automatically after 5 minutes (demo setting).
- You can drag & drop files from your desktop on this webpage (see Browser support).
- Please refer to the project website and documentation for more information.
- Built with Twitter's Bootstrap CSS framework and Icons from Glyphicons.